// Copyright (C) 2015 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
// Qt-Security score:significant reason:default

#ifndef QLOCATIONGLOBAL_H
#define QLOCATIONGLOBAL_H

#include <QtCore/qglobal.h>
#include <QtLocation/qtlocationexports.h>

#ifdef Q_CLANG_QDOC
#include <QtLocation/qlocation.h>
#endif

#endif // QLOCATIONGLOBAL_H

